pub const unsafe fn encode_imm32(imm32: Immediate32) -> EncodedX86_64InstructionExpand description
Call to RIP-relative address.
Safety
It is the caller’s responsibility to ensure that the operands are valid. Otherwise the behavior is undefined.
pub const unsafe fn encode_imm32(imm32: Immediate32) -> EncodedX86_64InstructionCall to RIP-relative address.
It is the caller’s responsibility to ensure that the operands are valid. Otherwise the behavior is undefined.